/***********************************************************************************
Note to User: The purpose of this program is to provide sample Stata code for running
weighted frequencies and means for the FMLA 2018 Worksite Survey, as well as for testing 
for differences across subgroups, using both worksite weights and employee weights.

Before running this program, please update the file path in the cd statement.
The file path in this statement should refer to the location on your computer where 
the FMLA 2018 Worksite Public Use File dataset (FMLA_2018_Worksite_PUF.dta) is saved.
***********************************************************************************/

cd "INSERT FILE PATH HERE"

use FMLA_2018_Worksite_PUF.dta



/*************************************************************************
Run weighted frequencies and means for FMLA 2018 Worksite Survey 
using worksite weights
*************************************************************************/

svyset [pw=estab_wt], vce(bootstrap) bsrw(bootstrap_estab_wt*) mse

/*Run weighted industry frequencies on full sample*/
svy: tab q4_cat

/*Run weighted mean percentage of female employees across full sample*/
svy: mean q7_pct 

/*Run weighted frequencies of industry on subsample of worksites that self-report being covered by FMLA*/
svy, subpop(if covered_self_reported==1): tab q4_cat

/*Run mean percentage of female employees by self-reported FMLA coverage status*/
svy: mean q7_pct, over(covered_self_reported) 

/*Test whether mean percentage of female employees differs by self-reported FMLA coverage status*/
svy: reg q7_pct i.covered_self_reported 


/*************************************************************************
Run weighted frequencies and means for FMLA 2018 Worksite Survey 
using employee weights
*************************************************************************/

svyset [pw=emp_wt], vce(bootstrap) bsrw(bootstrap_emp_wt*) mse

/*Run weighted industry frequencies on full sample*/
svy: tab q4_cat 

/*Run weighted mean percentage of female employees across full sample*/
svy: mean q7_pct 

/*Run weighted frequencies of industry on subsample of worksites that self-report being covered by FMLA*/
svy, subpop(if covered_self_reported ==1): tab q4_cat 

/*Run weighted mean percentage of female employees by self-reported FMLA coverage status*/
svy: mean q7_pct, over(covered_self_reported)

/*Test whether mean percentage of female employees differs by self-reported FMLA coverage status*/
svy: reg q7_pct i.covered_self_reported 
